==> itplugin-0.0.1.tar.gz: lib/controls/it_text_field.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:itplugin/extensions/string_extensions.dart';

class ItTextField extends StatefulWidget {
  final int maxLines;
  final bool isPassword;
  final Color bgColor;
  final Color focusColor;
  final Color cursorColor;
  final double linePadding;
  final Icon leftItem;
  final Icon rightItem;
  final String hintText;
  final TextStyle style;
  final TextInputType keyboardType;
  final String Function(String) validationFunction;
  final Function(String) onChanged;
  final EdgeInsetsGeometry contentPadding;
  final EdgeInsetsGeometry padding;
  final TextEditingController value;
  final List<TextInputFormatter> inputFormatter;
  final bool autoFocus;

  const ItTextField({
    this.maxLines = 1,
    this.isPassword = false,
    this.bgColor = Colors.white,
    this.focusColor = Colors.black87,
    this.cursorColor,
    this.linePadding = 10,
    this.leftItem,
    this.rightItem,
    this.hintText = "Dica",
    @required this.style,
    this.keyboardType,
    this.validationFunction,
    this.onChanged,
    this.contentPadding,
    this.padding,
    this.value,
    this.inputFormatter,
    this.autoFocus = false
  });

  @override
  _ItTextField createState() => _ItTextField();
}

class _ItTextField extends State<ItTextField> {
  Color statusColor = Colors.black;
  Color statusIconColor;

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: widget.padding,
      child: Column(children: <Widget>[
        TextFormField(
          autofocus: widget.autoFocus,
          controller: widget.value,
          validator: (value) {
            var valid = widget.validationFunction(value);
            if (!valid.isNullOrEmpty) {
              setState(() {
                statusColor = Colors.red;
                statusIconColor = Colors.red;
              });
            } else {
              setState(() {
                statusColor = Colors.black;
                statusIconColor = null;
              });
            }

            return valid;
          },
          cursorColor: widget.cursorColor,
          style: TextStyle(color: statusColor,fontSize: widget.style.fontSize),
          obscureText: widget.isPassword,
          inputFormatters: widget.inputFormatter,
          keyboardType: widget.keyboardType,
          maxLines: widget.maxLines,
          onChanged: widget.onChanged,
          textAlignVertical: TextAlignVertical.center,
          scrollPadding: EdgeInsets.all(10),
          decoration: InputDecoration(
            contentPadding: widget.contentPadding,
            filled: true,
            hintText: widget.hintText,
            prefixIcon: widget.leftItem != null ? Container(
              padding: widget.contentPadding,
              child: Icon(
                widget.leftItem.icon,
                size: widget.leftItem.size,
                color: statusIconColor,
              ),
            ): null,
            suffixIcon: widget.rightItem != null ? Container(
              padding: widget.contentPadding,
              child: Icon(
                widget.rightItem.icon,
                color: statusIconColor,
                size: widget.rightItem.size,
              ),
            ): null,
            alignLabelWithHint: true,
            focusedBorder: UnderlineInputBorder(
                borderSide: BorderSide(
                    style: BorderStyle.solid, color: Colors.transparent)),
            disabledBorder: UnderlineInputBorder(
                borderSide: BorderSide(
                    style: BorderStyle.solid, color: Colors.transparent)),
            enabledBorder: UnderlineInputBorder(
                borderSide: BorderSide(
                    style: BorderStyle.solid, color: Colors.transparent)),
            errorBorder: UnderlineInputBorder(
                borderSide: BorderSide(
                    style: BorderStyle.solid, color: Colors.transparent)),
            focusedErrorBorder: UnderlineInputBorder(
                borderSide: BorderSide(
                    style: BorderStyle.solid, color: Colors.transparent)),
            errorStyle: TextStyle(fontSize: 15),
          ),
        ),
        Container(
            margin: EdgeInsets.fromLTRB(0, widget.linePadding, 0, 0),
            height: 1,
            color: statusColor)
      ]),
    );
  }
}

==> itplugin-0.0.7.tar.gz: lib/controls/it_text_field.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:itplugin/extensions/string_extension.dart';

class ItTextField extends StatefulWidget {
  final int maxLines;
  final bool isPassword;
  final Color bgColor;
  final Color focusColor;
  final Color cursorColor;
  final Color textColor;
  final Color underlineColor;
  final double underlineOpacity;
  final double linePadding;
  final double lineHeight;
  final Icon leftItem;
  final Icon rightItem;
  final String hintText;
  final TextStyle style;
  final TextInputType keyboardType;
  final String Function(String) validationFunction;
  final Function(String) onChanged;
  final EdgeInsetsGeometry contentPadding;
  final EdgeInsetsGeometry padding;
  final TextEditingController value;
  final List<TextInputFormatter> inputFormatter;
  final bool autoFocus;

  const ItTextField(
      {this.maxLines = 1,
      this.isPassword = false,
      this.bgColor = Colors.white,
      this.focusColor = Colors.black87,
      this.textColor = Colors.black87,
      this.underlineColor = Colors.black87,
      this.underlineOpacity = 1,
      this.cursorColor,
      this.linePadding = 10,
      this.lineHeight = 1,
      this.leftItem,
      this.rightItem,
      this.hintText = "Dica",
      @required this.style,
      this.keyboardType,
      this.validationFunction,
      this.onChanged,
      this.contentPadding,
      this.padding,
      this.value,
      this.inputFormatter,
      this.autoFocus = false});

  @override
  _ItTextField createState() => _ItTextField();
}

class _ItTextField extends State<ItTextField> {
  Color statusColor;
  Color statusIconColor;

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: widget.padding,
      child: Column(children: <Widget>[
        TextFormField(
          autofocus: widget.autoFocus,
          controller: widget.value,
          validator: (value) {
            var valid = widget.validationFunction(value);
            if (!valid.isNullOrEmpty) {
              setState(() {
                statusColor = Colors.red;
                statusIconColor = Colors.red;
              });
            } else {
              setState(() {
                statusColor = null;
                statusIconColor = null;
              });
            }
            return valid;
          },
          cursorColor: widget.cursorColor,
          style: widget.style.merge(TextStyle(
              color: statusColor == null ? widget.textColor : statusColor)),
          obscureText: widget.isPassword,
          inputFormatters: widget.inputFormatter,
          keyboardType: widget.keyboardType,
          maxLines: widget.maxLines,
          onChanged: widget.onChanged,
          textAlignVertical: TextAlignVertical.center,
          scrollPadding: EdgeInsets.all(10),
          decoration: InputDecoration(
            contentPadding: widget.contentPadding,
            filled: true,
            focusColor: widget.focusColor,
            hintText: widget.hintText,
            fillColor: widget.bgColor,
            prefixIcon: widget.leftItem != null
                ? Container(
                    padding: widget.contentPadding,
                    child: Icon(
                      widget.leftItem.icon,
                      size: widget.leftItem.size,
                      color: statusIconColor,
                    ),
                  )
                : null,
            suffixIcon: widget.rightItem != null
                ? Container(
                    padding: widget.contentPadding,
                    child: Icon(
                      widget.rightItem.icon,
                      color: statusIconColor,
                      size: widget.rightItem.size,
                    ),
                  )
                : null,
            alignLabelWithHint: true,
            focusedBorder: UnderlineInputBorder(
                borderSide: BorderSide(
                    style: BorderStyle.solid, color: Colors.transparent)),
            disabledBorder: UnderlineInputBorder(
                borderSide: BorderSide(
                    style: BorderStyle.solid, color: Colors.transparent)),
            enabledBorder: UnderlineInputBorder(
                borderSide: BorderSide(
                    style: BorderStyle.solid, color: Colors.transparent)),
            errorBorder: UnderlineInputBorder(
                borderSide: BorderSide(
                    style: BorderStyle.solid, color: Colors.transparent)),
            focusedErrorBorder: UnderlineInputBorder(
                borderSide: BorderSide(
                    style: BorderStyle.solid, color: Colors.transparent)),
            errorStyle: TextStyle(fontSize: 15),
          ),
        ),
        Container(
            margin: EdgeInsets.fromLTRB(0, widget.linePadding, 0, 0),
            height: widget.lineHeight,
            color: statusColor != null
                ? statusColor.withOpacity(widget.underlineOpacity)
                : widget.underlineColor.withOpacity(widget.underlineOpacity))
      ]),
    );
  }
}
